Mounted

Struct Mounted 

pub struct Mounted(/* private fields */);
A path that becomes valid once we enter a chroot. We keep track of the base path of the chroot. The real path on the server is constructed by joining self.0 followed by the path.